@@ -1,30 +1,19 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
-from trytond.model import ModelView, ModelSQL, fields
+from trytond.model import ModelSQL, ModelView, fields
 from trytond.pool import Pool
 
-__all__ = ['Allocation']
-
 
 class Allocation(ModelSQL, ModelView):
     'Allocation'
     __name__ = 'project.allocation'
-    employee = fields.Many2One('company.employee', 'Employee', required=True,
-            select=True, ondelete='CASCADE')
-    work = fields.Many2One('project.work', 'Work', required=True,
-            select=True, ondelete='CASCADE')
+    employee = fields.Many2One(
+        'company.employee', "Employee", required=True, ondelete='CASCADE')
+    work = fields.Many2One(
+        'project.work', "Work", required=True, ondelete='CASCADE')
     percentage = fields.Float('Percentage', digits=(16, 2), required=True,
         domain=[('percentage', '>', 0.0)])
 
-    @classmethod
-    def __register__(cls, module_name):
-        super(Allocation, cls).__register__(module_name)
-
-        table = cls.__table_handler__(module_name)
-
-        # Migration from 3.2:
-        table.drop_constraint('percentage_positive')
-
     @staticmethod
     def default_percentage():
         return 100
