@@ -1,14 +1,14 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 import datetime
-from collections import deque, defaultdict
+from collections import defaultdict, deque
 from functools import reduce
 from heapq import heappop, heappush
 
 from trytond.model import ModelSQL, fields, tree
-from trytond.wizard import Wizard, StateTransition
-from trytond.pyson import Eval
 from trytond.pool import Pool, PoolMeta
+from trytond.pyson import Eval
+from trytond.wizard import StateTransition, Wizard
 
 
 def intfloor(x):
@@ -20,23 +20,21 @@ class Work(tree(parent='successors'), metaclass=PoolMeta):
     predecessors = fields.Many2Many('project.predecessor_successor',
         'successor', 'predecessor', 'Predecessors',
         domain=[
-            ('parent', '=', Eval('parent')),
-            ('id', '!=', Eval('id')),
-            ],
-        depends=['parent', 'id'])
+            ('parent', '=', Eval('parent', -1)),
+            ('id', '!=', Eval('id', -1)),
+            ])
     successors = fields.Many2Many('project.predecessor_successor',
         'predecessor', 'successor', 'Successors',
         domain=[
-            ('parent', '=', Eval('parent')),
-            ('id', '!=', Eval('id')),
-            ],
-        depends=['parent', 'id'])
+            ('parent', '=', Eval('parent', -1)),
+            ('id', '!=', Eval('id', -1)),
+            ])
     leveling_delay = fields.Float("Leveling Delay", required=True)
     back_leveling_delay = fields.Float("Back Leveling Delay", required=True)
     allocations = fields.One2Many('project.allocation', 'work', 'Allocations',
         states={
             'invisible': Eval('type') != 'task',
-            }, depends=['type'])
+            })
     duration = fields.Function(
         fields.TimeDelta('Duration', 'company_work_time'),
         'get_function_fields')
@@ -61,10 +59,10 @@ class Work(tree(parent='successors'), metaclass=PoolMeta):
     actual_finish_date = fields.Function(fields.Date('Actual Finish'),
             'get_function_fields', setter='set_function_fields')
     constraint_start_date = fields.Function(fields.Date('Constraint Start',
-        depends=['type']), 'get_function_fields',
+        depends={'type'}), 'get_function_fields',
         setter='set_function_fields')
     constraint_finish_date = fields.Function(fields.Date('Constraint Finish',
-        depends=['type']), 'get_function_fields',
+        depends={'type'}), 'get_function_fields',
         setter='set_function_fields')
 
     @classmethod
@@ -592,10 +590,10 @@ class Work(tree(parent='successors'), metaclass=PoolMeta):
 class PredecessorSuccessor(ModelSQL):
     'Predecessor - Successor'
     __name__ = 'project.predecessor_successor'
-    predecessor = fields.Many2One('project.work', 'Predecessor',
-            ondelete='CASCADE', required=True, select=True)
-    successor = fields.Many2One('project.work', 'Successor',
-            ondelete='CASCADE', required=True, select=True)
+    predecessor = fields.Many2One(
+        'project.work', "Predecessor", ondelete='CASCADE', required=True)
+    successor = fields.Many2One(
+        'project.work', "Successor", ondelete='CASCADE', required=True)
 
     @classmethod
     def write(cls, *args):
